@@ -414,50 +414,58 @@ impl<'tokens, 'src> Parser<'tokens, 'src> {
   /// Parse an expression, e.g. `1 + 2`
   fn parse_expression(&mut self) -> CompilationResult<'src, Expression<'src>> {
     if self.accepted_keyword(Keyword::If)? {
-      let lhs = self.parse_expression()?;
-
-      let inverted = self.accepted(BangEquals)?;
-
-      if !inverted {
-        self.expect(EqualsEquals)?;
-      }
-
-      let rhs = self.parse_expression()?;
-
-      self.expect(BraceL)?;
-
-      let then = self.parse_expression()?;
-
-      self.expect(BraceR)?;
-
-      self.expect_keyword(Keyword::Else)?;
-
-      self.expect(BraceL)?;
-
-      let otherwise = self.parse_expression()?;
-
-      self.expect(BraceR)?;
-
-      return Ok(Expression::Conditional {
-        lhs: Box::new(lhs),
-        rhs: Box::new(rhs),
-        then: Box::new(then),
-        otherwise: Box::new(otherwise),
-        inverted,
-      });
-    }
-
-    let value = self.parse_value()?;
-
-    if self.accepted(Plus)? {
-      let lhs = Box::new(value);
-      let rhs = Box::new(self.parse_expression()?);
-      Ok(Expression::Concatination { lhs, rhs })
+      self.parse_conditional()
     } else {
-      Ok(value)
+      let value = self.parse_value()?;
+
+      if self.accepted(Plus)? {
+        let lhs = Box::new(value);
+        let rhs = Box::new(self.parse_expression()?);
+        Ok(Expression::Concatination { lhs, rhs })
+      } else {
+        Ok(value)
+      }
     }
   }
 
+  /// Parse a conditional, e.g. `if a == b { "foo" } else { "bar" }`
+  fn parse_conditional(&mut self) -> CompilationResult<'src, Expression<'src>> {
+    let lhs = self.parse_expression()?;
+
+    let inverted = self.accepted(BangEquals)?;
+
+    if !inverted {
+      self.expect(EqualsEquals)?;
+    }
+
+    let rhs = self.parse_expression()?;
+
+    self.expect(BraceL)?;
+
+    let then = self.parse_expression()?;
+
+    self.expect(BraceR)?;
+
+    self.expect_keyword(Keyword::Else)?;
+
+    let otherwise = if self.accepted_keyword(Keyword::If)? {
+      self.parse_conditional()?
+    } else {
+      self.expect(BraceL)?;
+      let otherwise = self.parse_expression()?;
+      self.expect(BraceR)?;
+      otherwise
+    };
+
+    Ok(Expression::Conditional {
+      lhs: Box::new(lhs),
+      rhs: Box::new(rhs),
+      then: Box::new(then),
+      otherwise: Box::new(otherwise),
+      inverted,
+    })
+  }
+
   /// Parse a value, e.g. `(bar)`
   fn parse_value(&mut self) -> CompilationResult<'src, Expression<'src>> {
     if self.next_is(StringToken) {
@@ -619,19 +627,36 @@ impl<'tokens, 'src> Parser<'tokens, 'src> {
       dependencies.push(dependency);
     }
 
+    let priors = dependencies.len();
+
+    if self.accepted(AmpersandAmpersand)? {
+      let mut subsequents = Vec::new();
+
+      while let Some(subsequent) = self.accept_dependency()? {
+        subsequents.push(subsequent);
+      }
+
+      if subsequents.is_empty() {
+        return Err(self.unexpected_token()?);
+      }
+
+      dependencies.append(&mut subsequents);
+    }
+
     self.expect_eol()?;
 
     let body = self.parse_body()?;
 
     Ok(Recipe {
+      parameters: positional.into_iter().chain(variadic).collect(),
       private: name.lexeme().starts_with('_'),
       shebang: body.first().map(Line::is_shebang).unwrap_or(false),
-      parameters: positional.into_iter().chain(variadic).collect(),
+      priors,
+      body,
+      dependencies,
       doc,
       name,
       quiet,
-      dependencies,
-      body,
     })
   }
 
@@ -1094,6 +1119,12 @@ mod tests {
     tree: (justfile (recipe foo (deps (bar (+ 'a' 'b') (+ 'c' 'd'))))),
   }
 
+  test! {
+    name: recipe_subsequent,
+    text: "foo: && bar",
+    tree: (justfile (recipe foo (sups bar))),
+  }
+
   test! {
     name: recipe_line_single,
     text: "foo:\n bar",
@@ -1877,10 +1908,13 @@ mod tests {
     name:   missing_eol,
     input:  "a b c: z =",
     offset:  9,
-    line:   0,
-    column: 9,
-    width:  1,
-    kind:   UnexpectedToken{expected: vec![Comment, Eof, Eol, Identifier, ParenL], found: Equals},
+    line:    0,
+    column:  9,
+    width:   1,
+    kind:    UnexpectedToken{
+      expected: vec![AmpersandAmpersand, Comment, Eof, Eol, Identifier, ParenL],
+      found: Equals
+    },
   }
 
   error! {
