@@ -7,7 +7,14 @@ impl<'src> UnresolvedRecipe<'src> {
     self,
     resolved: Vec<Rc<Recipe<'src>>>,
   ) -> CompilationResult<'src, Recipe<'src>> {
-    assert_eq!(self.dependencies.len(), resolved.len());
+    assert_eq!(
+      self.dependencies.len(),
+      resolved.len(),
+      "UnresolvedRecipe::resolve: dependency count not equal to resolved count: {} != {}",
+      self.dependencies.len(),
+      resolved.len()
+    );
+
     for (unresolved, resolved) in self.dependencies.iter().zip(&resolved) {
       assert_eq!(unresolved.recipe.lexeme(), resolved.name.lexeme());
       if !resolved
@@ -36,13 +43,14 @@ impl<'src> UnresolvedRecipe<'src> {
       .collect();
 
     Ok(Recipe {
-      doc: self.doc,
       body: self.body,
+      doc: self.doc,
       name: self.name,
       parameters: self.parameters,
       private: self.private,
       quiet: self.quiet,
       shebang: self.shebang,
+      priors: self.priors,
       dependencies,
     })
   }
