@@ -1,17 +1,22 @@
 pub(crate) use std::{
   collections::BTreeMap,
   env::{self, consts::EXE_SUFFIX},
+  error::Error,
   fs,
   io::Write,
   iter,
   path::Path,
-  process::{Command, Stdio},
+  process::{Command, Output, Stdio},
   str,
 };
 
 pub(crate) use executable_path::executable_path;
 pub(crate) use just::unindent;
 pub(crate) use libc::{EXIT_FAILURE, EXIT_SUCCESS};
-pub(crate) use test_utilities::{assert_stdout, tempdir, tmptree};
+pub(crate) use temptree::temptree;
 pub(crate) use which::which;
 pub(crate) use yaml_rust::YamlLoader;
+
+pub(crate) use crate::{
+  assert_stdout::assert_stdout, assert_success::assert_success, tempdir::tempdir,
+};
