@@ -1131,85 +1131,6 @@ foo:
   stderr:   "echo abc\n",
 }
 
-test! {
-  name:     test_os_arch_functions_in_interpolation,
-  justfile: r#"
-foo:
-  echo {{arch()}} {{os()}} {{os_family()}}
-"#,
-  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-}
-
-test! {
-  name:     test_os_arch_functions_in_expression,
-  justfile: r#"
-a := arch()
-o := os()
-f := os_family()
-
-foo:
-  echo {{a}} {{o}} {{f}}
-"#,
-  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-}
-
-#[cfg(not(windows))]
-test! {
-  name:     env_var_functions,
-  justfile: r#"
-p := env_var('USER')
-b := env_var_or_default('ZADDY', 'HTAP')
-x := env_var_or_default('XYZ', 'ABC')
-
-foo:
-  /bin/echo '{{p}}' '{{b}}' '{{x}}'
-"#,
-  stdout:   format!("{} HTAP ABC\n", env::var("USER").unwrap()).as_str(),
-  stderr:   format!("/bin/echo '{}' 'HTAP' 'ABC'\n", env::var("USER").unwrap()).as_str(),
-}
-
-#[cfg(windows)]
-test! {
-  name:     env_var_functions,
-  justfile: r#"
-p := env_var('USERNAME')
-b := env_var_or_default('ZADDY', 'HTAP')
-x := env_var_or_default('XYZ', 'ABC')
-
-foo:
-  /bin/echo '{{p}}' '{{b}}' '{{x}}'
-"#,
-  stdout:   format!("{} HTAP ABC\n", env::var("USERNAME").unwrap()).as_str(),
-  stderr:   format!("/bin/echo '{}' 'HTAP' 'ABC'\n", env::var("USERNAME").unwrap()).as_str(),
-}
-
-test! {
-  name:     env_var_failure,
-  justfile: "a:\n  echo {{env_var('ZADDY')}}",
-  args:     ("a"),
-  stdout:   "",
-  stderr:   "error: Call to function `env_var` failed: environment variable `ZADDY` not present
-  |
-2 |   echo {{env_var('ZADDY')}}
-  |          ^^^^^^^
-",
-  status:   EXIT_FAILURE,
-}
-
-test! {
-  name:     test_just_executable_function,
-  justfile: "
-    a:
-      @printf 'Executable path is: %s\\n' '{{ just_executable() }}'
-  ",
-  args:     ("a"),
-  stdout:   format!("Executable path is: {}\n", executable_path("just").to_str().unwrap()).as_str(),
-  stderr:   "",
-  status:   EXIT_SUCCESS,
-}
-
 test! {
   name: infallable_command,
   justfile: r#"
@@ -1415,7 +1336,7 @@ test! {
   justfile: "foo: 'bar'",
   args:     ("foo"),
   stdout:   "",
-  stderr:   "error: Expected comment, end of file, end of line, \
+  stderr:   "error: Expected '&&', comment, end of file, end of line, \
     identifier, or '(', but found string
   |
 1 | foo: 'bar'
@@ -1489,6 +1410,25 @@ test! {
   status:   EXIT_FAILURE,
 }
 
+test! {
+  name:     variable_circular_dependency_with_additional_variable,
+  justfile: "
+    a := ''
+    x := y
+    y := x
+
+    a:
+  ",
+  args:     ("a"),
+  stdout:   "",
+  stderr:   "error: Variable `x` depends on its own value: `x -> y -> x`
+  |
+2 | x := y
+  | ^
+",
+  status:   EXIT_FAILURE,
+}
+
 test! {
   name:     plus_variadic_recipe,
   justfile: "
@@ -1862,16 +1802,6 @@ foo x=y:
    stderr:   "echo foo\n",
 }
 
-test! {
-  name:     test_os_arch_functions_in_default,
-  justfile: r#"
-foo a=arch() o=os() f=os_family():
-  echo {{a}} {{o}} {{f}}
-"#,
-  stdout:   format!("{} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-  stderr:   format!("echo {} {} {}\n", target::arch(), target::os(), target::os_family()).as_str(),
-}
-
 test! {
   name:     unterminated_interpolation_eol,
   justfile: "
